\name{LBL}
\alias{LBL}
%- Also NEED an '\alias' for EACH other topic documented here.

\title{
Bayesian Lasso for detecting Rare Haplotype-Environment Interaction
}

\description{
This function takes a dataset of haplotypes and environmental covariates in which rows for
     individuals of uncertain phase have been augmented by
     "pseudo-individuals" who carry the possible multilocus genotypes
     consistent with the single-locus phenotypes.
     Bayesian lasso is used to find the posterior
     distributions of logistic regression coefficients, which are then
     used to calculate Bayes Factor to test for association with haplotypes, environmental covariates and interactions.
     This function calls pre.hapassoc function from the hapassoc package, and some of the options such as "dat", "numSNPs", "maxMissingGenos" and "allelic" 
     are used by pre.hapassoc.
     Missing single-locus genotypes, up to a maximum of maxMissingGenos (see below), are allowed, but subjects with missing data in more than maxMissingGenos, 
     or with missing non-SNP data, are removed.
}

\usage{
LBL(dat, numSNPs, maxMissingGenos = 1, allelic = TRUE, haplo.baseline = "missing", cov.baseline = "missing", interaction = T, a = 20, b = 20, start.beta = 0.01, lambda = 1, D = 0, seed = NULL, e = 0.1, burn.in = 20000, num.it = 50000)
}
%- maybe also 'usage' for other objects documented here.

\arguments{
  \item{dat}{
the non-SNP and SNP data as a data frame. For the non-SNPdata, the first column is the affection status, others(optional) are environmental covariates. The SNP data should comprise the last 2*numSNPs columns (allelic format) or last numSNPs columns (genotypic format). Missing allelic data should be coded as NA or "" and missing genotypic data should be coded as, e.g., "A" if one allele is missing and "" if both alleles are missing.
}
  \item{numSNPs}{
number of SNPs per haplotype
}
  \item{maxMissingGenos}{
maximum number of single-locus genotypes with missing data to allow for each subject. (Subjects with more missing data, or with missing non-SNP data are removed.) The default is 1. 
}
  \item{allelic}{
TRUE if single-locus SNP genotypes are in allelic format and FALSE if in genotypic format; default is TRUE.
}
  \item{haplo.baseline}{
optional, haplotype to be used for baseline coding. Default
    is the most frequent haplotype according to the initial
    haplotype frequency estimates returned by pre.hapassoc.
}
  \item{cov.baseline}{
optional, covariates to be used for baseline coding. Default
    is a zero vector whose length is the number of covariates.
}
  \item{interaction}{
indicator, indicating whether or not to put gene-environment interactions in your model; default is TRUE.
}
  \item{a}{
first hyperparameter of the prior for regression coefficients, beta. The
  prior variance of beta is 2/lambda^2 and lambda has Gamma(a,b)
  prior. The Gamma parameters a and b are such that the mean and
  variance of the Gamma distribution are a/b and a/b^2.
}
  \item{b}{
b parameter of the Gamma(a,b) distribution described above.
}
  \item{start.beta}{
starting value of all regression coefficients, beta.
}
  \item{lambda}{
starting value of the lambda parameter described above.
}
  \item{D}{
starting value of the D parameter, which is the within-population
     inbreeding coefficient.
}
  \item{seed}{
the seed to be used for the MCMC in Bayesian Lasso.
}
  \item{e}{
A (small) number epsilon in the null hypothesis of no association,
    H0: |beta| <= epsilon. Changing e from default of 0.1 may need choosing a
     different threshold for Bayes Factor (one of the outputs) to
     infer association.
}
  \item{burn.in}{
Burn-in period of the MCMC sampling scheme.
}
  \item{num.it}{
Total number of MCMC iterations including the burn-in iterations.
}
}

\value{
  \item{BF }{A vector of Bayes Factors for all regression
    coefficients. If BF exceeds a cetain threshold (e.g., 2 or 3)
    association can be concluded.}
  \item{OR }{A vector of estimated odds ratios of the corresponding haplotype against the reference haplotype (haplo.baseline). This is the exponentoal of the posterior means of the regression coefficients}
  \item{CI.OR }{95\% credible sets for the ORs}
  \item{freq }{A vector of posterior means of the haplotype frequencies}
  \item{CI.freq }{95\% credible sets for each haplotype frequency}
  \item{CI.lambda }{95\% credible sets for the lambda parameter as
    described above}
  \item{CI.D }{95\% credible sets for D as described above}
}

\references{
Biswas S, Xia S, Lin S (2013). Detecting Rare Haplotype-Environment Interaction with Logistic Bayesian LASSO. Genetic Epidemiology.

Biswas S, Lin S (2011). Logistic Bayesian LASSO for identifying association with rare haplotypes and application to age-related macular degeneration. Biometrics 68(2):587-97.

Burkett K, Graham J and McNeney B (2006). hapassoc: Software for
     Likelihood Inference of Trait Associations with SNP Haplotypes and
     Other Attributes. Journal of Statistical Software, *16(2)*:1-19
}

\author{
Shuang Xia, Swati Biswas, Shili Lin
}

\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
'pre.hapassoc', 'hapassoc', 'rGLM'
}

\examples{
# Load an example data
data(LBL.ex)

#Install hapassoc and dummies package
library(hapassoc)
library(dummies)

## Run LBL to make inference on association of haplotypes with the disease. Note the defaul setting are burn.in = 10000, num.it = 50000 in the LBL function. However, you may want to use smaller numbers for a quick check to make sure the package is loded properly.

out.LBL<-LBL(LBL.ex, numSNPs=5, burn.in=100, num.it=1000)
}
